# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/service/service_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2
from prodvana.proto.prodvana.service import parameters_pb2 as prodvana_dot_service_dot_parameters__pb2
from prodvana.proto.prodvana.service import service_config_pb2 as prodvana_dot_service_dot_service__config__pb2
from prodvana.proto.prodvana.service import user_metadata_pb2 as prodvana_dot_service_dot_user__metadata__pb2
from prodvana.proto.prodvana.service import object_pb2 as prodvana_dot_service_dot_object__pb2
from prodvana.proto.prodvana.stat import efficiency_pb2 as prodvana_dot_stat_dot_efficiency__pb2
from prodvana.proto.prodvana.metrics import metrics_pb2 as prodvana_dot_metrics_dot_metrics__pb2
from prodvana.proto.prodvana.insights import insights_pb2 as prodvana_dot_insights_dot_insights__pb2
from prodvana.proto.prodvana.repo import repo_pb2 as prodvana_dot_repo_dot_repo__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&prodvana/service/service_manager.proto\x12\x10prodvana.service\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'prodvana/common_config/parameters.proto\x1a!prodvana/service/parameters.proto\x1a%prodvana/service/service_config.proto\x1a$prodvana/service/user_metadata.proto\x1a\x1dprodvana/service/object.proto\x1a\x1eprodvana/stat/efficiency.proto\x1a\x1eprodvana/metrics/metrics.proto\x1a prodvana/insights/insights.proto\x1a\x18prodvana/repo/repo.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"w\n\x1dServiceConfigVersionReference\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\'\n\x16service_config_version\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xb5\x05\n\x12\x41pplyParametersReq\x12\x39\n\x0eservice_config\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfigH\x00\x12Q\n\x16service_config_version\x18\x08 \x01(\x0b\x32/.prodvana.service.ServiceConfigVersionReferenceH\x00\x12I\n\nparameters\x18\t \x03(\x0b\x32&.prodvana.common_config.ParameterValueB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x62\n\x13per_release_channel\x18\n \x03(\x0b\x32\x36.prodvana.service.ApplyParametersReq.PerReleaseChannelB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12%\n\x1dtest_only_skip_registry_check\x18\x04 \x01(\x08\x12\x13\n\x0b\x61pplication\x18\x05 \x01(\t\x12(\n\x06source\x18\x06 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x07 \x01(\x0b\x32 .prodvana.version.SourceMetadata\x1a\x80\x01\n\x11PerReleaseChannel\x12 \n\x0frelease_channel\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12I\n\nparameters\x18\x02 \x03(\x0b\x32&.prodvana.common_config.ParameterValueB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x42\x0c\n\x05oneof\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04R\x10release_channelsR\x12\x63ompute_efficiency\"r\n\x13\x41pplyParametersResp\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x36\n\x0f\x65\x66\x66iciency_stat\x18\x03 \x01(\x0b\x32\x1d.prodvana.stat.EfficiencyStat\"\xf9\x01\n\x1bValidateApplyParametersResp\x12/\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x38\n\x0f\x63ompiled_config\x18\x02 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x13\n\x0b\x61pp_version\x18\x03 \x01(\t\x12Z\n!compiled_service_instance_configs\x18\x04 \x03(\x0b\x32/.prodvana.service.CompiledServiceInstanceConfig\"Z\n\x18GetMaterializedConfigReq\x12\x18\n\x07service\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\"\xd3\x02\n\x19GetMaterializedConfigResp\x12/\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x38\n\x0f\x63ompiled_config\x18\x03 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12Z\n!compiled_service_instance_configs\x18\x04 \x03(\x0b\x32/.prodvana.service.CompiledServiceInstanceConfig\x12^\n\x10version_metadata\x18\x05 \x01(\x0b\x32\x44.prodvana.service.ListMaterializedConfigVersionsResp.VersionMetadata\"A\n\x10\x44\x65leteServiceReq\x12\x18\n\x07service\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x61pplication\x18\x02 \x01(\t\"\x13\n\x11\x44\x65leteServiceResp\"A\n\x0fListServicesReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x10\n\x08\x64\x65tailed\x18\x02 \x01(\x08\"?\n\x10ListServicesResp\x12+\n\x08services\x18\x01 \x03(\x0b\x32\x19.prodvana.service.Service\"G\n\rGetServiceReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"<\n\x0eGetServiceResp\x12*\n\x07service\x18\x01 \x01(\x0b\x32\x19.prodvana.service.Service\"Q\n\x17ListServiceInstancesReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"X\n\x18ListServiceInstancesResp\x12<\n\x11service_instances\x18\x01 \x03(\x0b\x32!.prodvana.service.ServiceInstance\"q\n\x15GetServiceInstanceReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x0frelease_channel\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"U\n\x16GetServiceInstanceResp\x12;\n\x10service_instance\x18\x01 \x01(\x0b\x32!.prodvana.service.ServiceInstance\"\xcc\x01\n\x14GetServiceMetricsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x33\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cinclude_cost\x18\x05 \x01(\x08\"~\n\x15GetServiceMetricsResp\x12?\n\x12\x64\x65ployment_metrics\x18\x01 \x01(\x0b\x32#.prodvana.metrics.DeploymentMetrics\x12$\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x16.prodvana.metrics.Cost\"O\n\x15GetServiceInsightsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"o\n\x0eListCommitsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"R\n\x0fListCommitsResp\x12&\n\x07\x63ommits\x18\x01 \x03(\x0b\x32\x15.prodvana.repo.Commit\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"F\n\x16GetServiceInsightsResp\x12,\n\x08insights\x18\x01 \x03(\x0b\x32\x1a.prodvana.insights.Insight\"\xbd\x01\n\x17SnoozeServiceInsightReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x31\n\x05\x63lass\x18\x03 \x01(\x0e\x32\x18.prodvana.insights.ClassB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x37\n\x08\x64uration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\"\x1a\n\x18SnoozeServiceInsightResp\"O\n\x15GetServiceMetadataReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"Q\n\x16GetServiceMetadataResp\x12\x37\n\x08metadata\x18\x01 \x01(\x0b\x32%.prodvana.service.ServiceUserMetadata\"\x92\x01\n\x15SetServiceMetadataReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x41\n\x08metadata\x18\x03 \x01(\x0b\x32%.prodvana.service.ServiceUserMetadataB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x18\n\x16SetServiceMetadataResp\"\x82\x01\n!ListMaterializedConfigVersionsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"\xad\x03\n\"ListMaterializedConfigVersionsResp\x12V\n\x08versions\x18\x01 \x03(\x0b\x32\x44.prodvana.service.ListMaterializedConfigVersionsResp.VersionMetadata\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\x95\x02\n\x0fVersionMetadata\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x63onfig_version\x18\x03 \x01(\t\x12<\n\nparameters\x18\x04 \x01(\x0b\x32(.prodvana.service.ServiceParameterValues\x12(\n\x06source\x18\x05 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x06 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"\xdb\x01\n\x13\x43onfigureServiceReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x41\n\x0eservice_config\x18\x02 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"B\n\x14\x43onfigureServiceResp\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63onfig_version\x18\x02 \x01(\t\"}\n\x1cListServiceConfigVersionsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"\xcd\x02\n\x1dListServiceConfigVersionsResp\x12Q\n\x08versions\x18\x01 \x03(\x0b\x32?.prodvana.service.ListServiceConfigVersionsResp.VersionMetadata\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\xbf\x01\n\x0fVersionMetadata\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"e\n\x13GetServiceConfigReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x0e\x63onfig_version\x18\x03 \x01(\t\"\xc1\x01\n\x14GetServiceConfigResp\x12/\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x16\n\x0e\x63onfig_version\x18\x02 \x01(\t\x12`\n\x17\x63onfig_version_metadata\x18\x03 \x01(\x0b\x32?.prodvana.service.ListServiceConfigVersionsResp.VersionMetadata2\xcb\x18\n\x0eServiceManager\x12\x95\x01\n\x10\x43onfigureService\x12%.prodvana.service.ConfigureServiceReq\x1a&.prodvana.service.ConfigureServiceResp\"2\x82\xd3\xe4\x93\x02,\"\'/v1/{application=*}/services/configure2:\x01*\x12\xbe\x01\n\x19ListServiceConfigVersions\x12..prodvana.service.ListServiceConfigVersionsReq\x1a/.prodvana.service.ListServiceConfigVersionsResp\"@\x82\xd3\xe4\x93\x02:\x12\x38/v1/{application=*}/services/{service=*}/config/versions\x12\x9a\x01\n\x10GetServiceConfig\x12%.prodvana.service.GetServiceConfigReq\x1a&.prodvana.service.GetServiceConfigResp\"7\x82\xd3\xe4\x93\x02\x31\x12//v1/{application=*}/services/{service=*}/config\x12\x98\x01\n\x0f\x41pplyParameters\x12$.prodvana.service.ApplyParametersReq\x1a%.prodvana.service.ApplyParametersResp\"8\x82\xd3\xe4\x93\x02\x32\"-/v1/{application=*}/services/apply-parameters:\x01*\x12\xb1\x01\n\x17ValidateApplyParameters\x12$.prodvana.service.ApplyParametersReq\x1a-.prodvana.service.ValidateApplyParametersResp\"A\x82\xd3\xe4\x93\x02;\"6/v1/{application=*}/services/apply-parameters/validate:\x01*\x12\xb6\x01\n\x15GetMaterializedConfig\x12*.prodvana.service.GetMaterializedConfigReq\x1a+.prodvana.service.GetMaterializedConfigResp\"D\x82\xd3\xe4\x93\x02>\x12</v1/{application=*}/services/{service=*}/materialized/config\x12\xda\x01\n\x1eListMaterializedConfigVersions\x12\x33.prodvana.service.ListMaterializedConfigVersionsReq\x1a\x34.prodvana.service.ListMaterializedConfigVersionsResp\"M\x82\xd3\xe4\x93\x02G\x12\x45/v1/{application=*}/services/{service=*}/materialized/config/versions\x12\x91\x01\n\rDeleteService\x12\".prodvana.service.DeleteServiceReq\x1a#.prodvana.service.DeleteServiceResp\"7\x82\xd3\xe4\x93\x02\x31*//v1/{application=*}/services/{service=*}/delete\x12\x88\x01\n\x0cListServices\x12!.prodvana.service.ListServicesReq\x1a\".prodvana.service.ListServicesResp\"1\x82\xd3\xe4\x93\x02+\x12)/v1/applications/{application=*}/services\x12\x99\x01\n\x0bListCommits\x12 .prodvana.service.ListCommitsReq\x1a!.prodvana.service.ListCommitsResp\"E\x82\xd3\xe4\x93\x02?\x12=/v1/applications/{application=*}/services/{service=*}/commits\x12\x8e\x01\n\nGetService\x12\x1f.prodvana.service.GetServiceReq\x1a .prodvana.service.GetServiceResp\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v1/applications/{application=*}/services/{service=*}\x12\xbd\x01\n\x14ListServiceInstances\x12).prodvana.service.ListServiceInstancesReq\x1a*.prodvana.service.ListServiceInstancesResp\"N\x82\xd3\xe4\x93\x02H\x12\x46/v1/applications/{application=*}/services/{service=*}/release-channels\x12\xcb\x01\n\x12GetServiceInstance\x12\'.prodvana.service.GetServiceInstanceReq\x1a(.prodvana.service.GetServiceInstanceResp\"b\x82\xd3\xe4\x93\x02\\\x12Z/v1/applications/{application=*}/services/{service=*}/release-channels/{release_channel=*}\x12\xab\x01\n\x11GetServiceMetrics\x12&.prodvana.service.GetServiceMetricsReq\x1a\'.prodvana.service.GetServiceMetricsResp\"E\x82\xd3\xe4\x93\x02?\x12=/v1/applications/{application=*}/services/{service=*}/metrics\x12\xaf\x01\n\x12GetServiceInsights\x12\'.prodvana.service.GetServiceInsightsReq\x1a(.prodvana.service.GetServiceInsightsResp\"F\x82\xd3\xe4\x93\x02@\x12>/v1/applications/{application=*}/services/{service=*}/insights\x12\xbc\x01\n\x14SnoozeServiceInsight\x12).prodvana.service.SnoozeServiceInsightReq\x1a*.prodvana.service.SnoozeServiceInsightResp\"M\x82\xd3\xe4\x93\x02G\x1a\x45/v1/applications/{application=*}/services/{service=*}/insights/snooze\x12\xaf\x01\n\x12GetServiceMetadata\x12\'.prodvana.service.GetServiceMetadataReq\x1a(.prodvana.service.GetServiceMetadataResp\"F\x82\xd3\xe4\x93\x02@\x12>/v1/applications/{application=*}/services/{service=*}/metadata\x12\xb2\x01\n\x12SetServiceMetadata\x12\'.prodvana.service.SetServiceMetadataReq\x1a(.prodvana.service.SetServiceMetadataResp\"I\x82\xd3\xe4\x93\x02\x43\">/v1/applications/{application=*}/services/{service=*}/metadata:\x01*BLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/serviceb\x06proto3')



_SERVICECONFIGVERSIONREFERENCE = DESCRIPTOR.message_types_by_name['ServiceConfigVersionReference']
_APPLYPARAMETERSREQ = DESCRIPTOR.message_types_by_name['ApplyParametersReq']
_APPLYPARAMETERSREQ_PERRELEASECHANNEL = _APPLYPARAMETERSREQ.nested_types_by_name['PerReleaseChannel']
_APPLYPARAMETERSRESP = DESCRIPTOR.message_types_by_name['ApplyParametersResp']
_VALIDATEAPPLYPARAMETERSRESP = DESCRIPTOR.message_types_by_name['ValidateApplyParametersResp']
_GETMATERIALIZEDCONFIGREQ = DESCRIPTOR.message_types_by_name['GetMaterializedConfigReq']
_GETMATERIALIZEDCONFIGRESP = DESCRIPTOR.message_types_by_name['GetMaterializedConfigResp']
_DELETESERVICEREQ = DESCRIPTOR.message_types_by_name['DeleteServiceReq']
_DELETESERVICERESP = DESCRIPTOR.message_types_by_name['DeleteServiceResp']
_LISTSERVICESREQ = DESCRIPTOR.message_types_by_name['ListServicesReq']
_LISTSERVICESRESP = DESCRIPTOR.message_types_by_name['ListServicesResp']
_GETSERVICEREQ = DESCRIPTOR.message_types_by_name['GetServiceReq']
_GETSERVICERESP = DESCRIPTOR.message_types_by_name['GetServiceResp']
_LISTSERVICEINSTANCESREQ = DESCRIPTOR.message_types_by_name['ListServiceInstancesReq']
_LISTSERVICEINSTANCESRESP = DESCRIPTOR.message_types_by_name['ListServiceInstancesResp']
_GETSERVICEINSTANCEREQ = DESCRIPTOR.message_types_by_name['GetServiceInstanceReq']
_GETSERVICEINSTANCERESP = DESCRIPTOR.message_types_by_name['GetServiceInstanceResp']
_GETSERVICEMETRICSREQ = DESCRIPTOR.message_types_by_name['GetServiceMetricsReq']
_GETSERVICEMETRICSRESP = DESCRIPTOR.message_types_by_name['GetServiceMetricsResp']
_GETSERVICEINSIGHTSREQ = DESCRIPTOR.message_types_by_name['GetServiceInsightsReq']
_LISTCOMMITSREQ = DESCRIPTOR.message_types_by_name['ListCommitsReq']
_LISTCOMMITSRESP = DESCRIPTOR.message_types_by_name['ListCommitsResp']
_GETSERVICEINSIGHTSRESP = DESCRIPTOR.message_types_by_name['GetServiceInsightsResp']
_SNOOZESERVICEINSIGHTREQ = DESCRIPTOR.message_types_by_name['SnoozeServiceInsightReq']
_SNOOZESERVICEINSIGHTRESP = DESCRIPTOR.message_types_by_name['SnoozeServiceInsightResp']
_GETSERVICEMETADATAREQ = DESCRIPTOR.message_types_by_name['GetServiceMetadataReq']
_GETSERVICEMETADATARESP = DESCRIPTOR.message_types_by_name['GetServiceMetadataResp']
_SETSERVICEMETADATAREQ = DESCRIPTOR.message_types_by_name['SetServiceMetadataReq']
_SETSERVICEMETADATARESP = DESCRIPTOR.message_types_by_name['SetServiceMetadataResp']
_LISTMATERIALIZEDCONFIGVERSIONSREQ = DESCRIPTOR.message_types_by_name['ListMaterializedConfigVersionsReq']
_LISTMATERIALIZEDCONFIGVERSIONSRESP = DESCRIPTOR.message_types_by_name['ListMaterializedConfigVersionsResp']
_LISTMATERIALIZEDCONFIGVERSIONSRESP_VERSIONMETADATA = _LISTMATERIALIZEDCONFIGVERSIONSRESP.nested_types_by_name['VersionMetadata']
_CONFIGURESERVICEREQ = DESCRIPTOR.message_types_by_name['ConfigureServiceReq']
_CONFIGURESERVICERESP = DESCRIPTOR.message_types_by_name['ConfigureServiceResp']
_LISTSERVICECONFIGVERSIONSREQ = DESCRIPTOR.message_types_by_name['ListServiceConfigVersionsReq']
_LISTSERVICECONFIGVERSIONSRESP = DESCRIPTOR.message_types_by_name['ListServiceConfigVersionsResp']
_LISTSERVICECONFIGVERSIONSRESP_VERSIONMETADATA = _LISTSERVICECONFIGVERSIONSRESP.nested_types_by_name['VersionMetadata']
_GETSERVICECONFIGREQ = DESCRIPTOR.message_types_by_name['GetServiceConfigReq']
_GETSERVICECONFIGRESP = DESCRIPTOR.message_types_by_name['GetServiceConfigResp']
ServiceConfigVersionReference = _reflection.GeneratedProtocolMessageType('ServiceConfigVersionReference', (_message.Message,), {
  'DESCRIPTOR' : _SERVICECONFIGVERSIONREFERENCE,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ServiceConfigVersionReference)
  })
_sym_db.RegisterMessage(ServiceConfigVersionReference)

ApplyParametersReq = _reflection.GeneratedProtocolMessageType('ApplyParametersReq', (_message.Message,), {

  'PerReleaseChannel' : _reflection.GeneratedProtocolMessageType('PerReleaseChannel', (_message.Message,), {
    'DESCRIPTOR' : _APPLYPARAMETERSREQ_PERRELEASECHANNEL,
    '__module__' : 'prodvana.service.service_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.service.ApplyParametersReq.PerReleaseChannel)
    })
  ,
  'DESCRIPTOR' : _APPLYPARAMETERSREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ApplyParametersReq)
  })
_sym_db.RegisterMessage(ApplyParametersReq)
_sym_db.RegisterMessage(ApplyParametersReq.PerReleaseChannel)

ApplyParametersResp = _reflection.GeneratedProtocolMessageType('ApplyParametersResp', (_message.Message,), {
  'DESCRIPTOR' : _APPLYPARAMETERSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ApplyParametersResp)
  })
_sym_db.RegisterMessage(ApplyParametersResp)

ValidateApplyParametersResp = _reflection.GeneratedProtocolMessageType('ValidateApplyParametersResp', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEAPPLYPARAMETERSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ValidateApplyParametersResp)
  })
_sym_db.RegisterMessage(ValidateApplyParametersResp)

GetMaterializedConfigReq = _reflection.GeneratedProtocolMessageType('GetMaterializedConfigReq', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZEDCONFIGREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetMaterializedConfigReq)
  })
_sym_db.RegisterMessage(GetMaterializedConfigReq)

GetMaterializedConfigResp = _reflection.GeneratedProtocolMessageType('GetMaterializedConfigResp', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZEDCONFIGRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetMaterializedConfigResp)
  })
_sym_db.RegisterMessage(GetMaterializedConfigResp)

DeleteServiceReq = _reflection.GeneratedProtocolMessageType('DeleteServiceReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVICEREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.DeleteServiceReq)
  })
_sym_db.RegisterMessage(DeleteServiceReq)

DeleteServiceResp = _reflection.GeneratedProtocolMessageType('DeleteServiceResp', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVICERESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.DeleteServiceResp)
  })
_sym_db.RegisterMessage(DeleteServiceResp)

ListServicesReq = _reflection.GeneratedProtocolMessageType('ListServicesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListServicesReq)
  })
_sym_db.RegisterMessage(ListServicesReq)

ListServicesResp = _reflection.GeneratedProtocolMessageType('ListServicesResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListServicesResp)
  })
_sym_db.RegisterMessage(ListServicesResp)

GetServiceReq = _reflection.GeneratedProtocolMessageType('GetServiceReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceReq)
  })
_sym_db.RegisterMessage(GetServiceReq)

GetServiceResp = _reflection.GeneratedProtocolMessageType('GetServiceResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICERESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceResp)
  })
_sym_db.RegisterMessage(GetServiceResp)

ListServiceInstancesReq = _reflection.GeneratedProtocolMessageType('ListServiceInstancesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICEINSTANCESREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListServiceInstancesReq)
  })
_sym_db.RegisterMessage(ListServiceInstancesReq)

ListServiceInstancesResp = _reflection.GeneratedProtocolMessageType('ListServiceInstancesResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICEINSTANCESRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListServiceInstancesResp)
  })
_sym_db.RegisterMessage(ListServiceInstancesResp)

GetServiceInstanceReq = _reflection.GeneratedProtocolMessageType('GetServiceInstanceReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEINSTANCEREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceInstanceReq)
  })
_sym_db.RegisterMessage(GetServiceInstanceReq)

GetServiceInstanceResp = _reflection.GeneratedProtocolMessageType('GetServiceInstanceResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEINSTANCERESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceInstanceResp)
  })
_sym_db.RegisterMessage(GetServiceInstanceResp)

GetServiceMetricsReq = _reflection.GeneratedProtocolMessageType('GetServiceMetricsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEMETRICSREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceMetricsReq)
  })
_sym_db.RegisterMessage(GetServiceMetricsReq)

GetServiceMetricsResp = _reflection.GeneratedProtocolMessageType('GetServiceMetricsResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEMETRICSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceMetricsResp)
  })
_sym_db.RegisterMessage(GetServiceMetricsResp)

GetServiceInsightsReq = _reflection.GeneratedProtocolMessageType('GetServiceInsightsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEINSIGHTSREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceInsightsReq)
  })
_sym_db.RegisterMessage(GetServiceInsightsReq)

ListCommitsReq = _reflection.GeneratedProtocolMessageType('ListCommitsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMITSREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListCommitsReq)
  })
_sym_db.RegisterMessage(ListCommitsReq)

ListCommitsResp = _reflection.GeneratedProtocolMessageType('ListCommitsResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMITSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListCommitsResp)
  })
_sym_db.RegisterMessage(ListCommitsResp)

GetServiceInsightsResp = _reflection.GeneratedProtocolMessageType('GetServiceInsightsResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEINSIGHTSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceInsightsResp)
  })
_sym_db.RegisterMessage(GetServiceInsightsResp)

SnoozeServiceInsightReq = _reflection.GeneratedProtocolMessageType('SnoozeServiceInsightReq', (_message.Message,), {
  'DESCRIPTOR' : _SNOOZESERVICEINSIGHTREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.SnoozeServiceInsightReq)
  })
_sym_db.RegisterMessage(SnoozeServiceInsightReq)

SnoozeServiceInsightResp = _reflection.GeneratedProtocolMessageType('SnoozeServiceInsightResp', (_message.Message,), {
  'DESCRIPTOR' : _SNOOZESERVICEINSIGHTRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.SnoozeServiceInsightResp)
  })
_sym_db.RegisterMessage(SnoozeServiceInsightResp)

GetServiceMetadataReq = _reflection.GeneratedProtocolMessageType('GetServiceMetadataReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEMETADATAREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceMetadataReq)
  })
_sym_db.RegisterMessage(GetServiceMetadataReq)

GetServiceMetadataResp = _reflection.GeneratedProtocolMessageType('GetServiceMetadataResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEMETADATARESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceMetadataResp)
  })
_sym_db.RegisterMessage(GetServiceMetadataResp)

SetServiceMetadataReq = _reflection.GeneratedProtocolMessageType('SetServiceMetadataReq', (_message.Message,), {
  'DESCRIPTOR' : _SETSERVICEMETADATAREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.SetServiceMetadataReq)
  })
_sym_db.RegisterMessage(SetServiceMetadataReq)

SetServiceMetadataResp = _reflection.GeneratedProtocolMessageType('SetServiceMetadataResp', (_message.Message,), {
  'DESCRIPTOR' : _SETSERVICEMETADATARESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.SetServiceMetadataResp)
  })
_sym_db.RegisterMessage(SetServiceMetadataResp)

ListMaterializedConfigVersionsReq = _reflection.GeneratedProtocolMessageType('ListMaterializedConfigVersionsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZEDCONFIGVERSIONSREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListMaterializedConfigVersionsReq)
  })
_sym_db.RegisterMessage(ListMaterializedConfigVersionsReq)

ListMaterializedConfigVersionsResp = _reflection.GeneratedProtocolMessageType('ListMaterializedConfigVersionsResp', (_message.Message,), {

  'VersionMetadata' : _reflection.GeneratedProtocolMessageType('VersionMetadata', (_message.Message,), {
    'DESCRIPTOR' : _LISTMATERIALIZEDCONFIGVERSIONSRESP_VERSIONMETADATA,
    '__module__' : 'prodvana.service.service_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.service.ListMaterializedConfigVersionsResp.VersionMetadata)
    })
  ,
  'DESCRIPTOR' : _LISTMATERIALIZEDCONFIGVERSIONSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListMaterializedConfigVersionsResp)
  })
_sym_db.RegisterMessage(ListMaterializedConfigVersionsResp)
_sym_db.RegisterMessage(ListMaterializedConfigVersionsResp.VersionMetadata)

ConfigureServiceReq = _reflection.GeneratedProtocolMessageType('ConfigureServiceReq', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURESERVICEREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ConfigureServiceReq)
  })
_sym_db.RegisterMessage(ConfigureServiceReq)

ConfigureServiceResp = _reflection.GeneratedProtocolMessageType('ConfigureServiceResp', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURESERVICERESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ConfigureServiceResp)
  })
_sym_db.RegisterMessage(ConfigureServiceResp)

ListServiceConfigVersionsReq = _reflection.GeneratedProtocolMessageType('ListServiceConfigVersionsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICECONFIGVERSIONSREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListServiceConfigVersionsReq)
  })
_sym_db.RegisterMessage(ListServiceConfigVersionsReq)

ListServiceConfigVersionsResp = _reflection.GeneratedProtocolMessageType('ListServiceConfigVersionsResp', (_message.Message,), {

  'VersionMetadata' : _reflection.GeneratedProtocolMessageType('VersionMetadata', (_message.Message,), {
    'DESCRIPTOR' : _LISTSERVICECONFIGVERSIONSRESP_VERSIONMETADATA,
    '__module__' : 'prodvana.service.service_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.service.ListServiceConfigVersionsResp.VersionMetadata)
    })
  ,
  'DESCRIPTOR' : _LISTSERVICECONFIGVERSIONSRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ListServiceConfigVersionsResp)
  })
_sym_db.RegisterMessage(ListServiceConfigVersionsResp)
_sym_db.RegisterMessage(ListServiceConfigVersionsResp.VersionMetadata)

GetServiceConfigReq = _reflection.GeneratedProtocolMessageType('GetServiceConfigReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICECONFIGREQ,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceConfigReq)
  })
_sym_db.RegisterMessage(GetServiceConfigReq)

GetServiceConfigResp = _reflection.GeneratedProtocolMessageType('GetServiceConfigResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICECONFIGRESP,
  '__module__' : 'prodvana.service.service_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.GetServiceConfigResp)
  })
_sym_db.RegisterMessage(GetServiceConfigResp)

_SERVICEMANAGER = DESCRIPTOR.services_by_name['ServiceManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/service'
  _SERVICECONFIGVERSIONREFERENCE.fields_by_name['service']._options = None
  _SERVICECONFIGVERSIONREFERENCE.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SERVICECONFIGVERSIONREFERENCE.fields_by_name['service_config_version']._options = None
  _SERVICECONFIGVERSIONREFERENCE.fields_by_name['service_config_version']._serialized_options = b'\372B\004r\002\020\001'
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL.fields_by_name['release_channel']._options = None
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL.fields_by_name['parameters']._options = None
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _APPLYPARAMETERSREQ.oneofs_by_name['oneof']._options = None
  _APPLYPARAMETERSREQ.oneofs_by_name['oneof']._serialized_options = b'\370B\001'
  _APPLYPARAMETERSREQ.fields_by_name['parameters']._options = None
  _APPLYPARAMETERSREQ.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _APPLYPARAMETERSREQ.fields_by_name['per_release_channel']._options = None
  _APPLYPARAMETERSREQ.fields_by_name['per_release_channel']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _GETMATERIALIZEDCONFIGREQ.fields_by_name['service']._options = None
  _GETMATERIALIZEDCONFIGREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _DELETESERVICEREQ.fields_by_name['service']._options = None
  _DELETESERVICEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICESREQ.fields_by_name['application']._options = None
  _LISTSERVICESREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEREQ.fields_by_name['application']._options = None
  _GETSERVICEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEREQ.fields_by_name['service']._options = None
  _GETSERVICEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICEINSTANCESREQ.fields_by_name['application']._options = None
  _LISTSERVICEINSTANCESREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICEINSTANCESREQ.fields_by_name['service']._options = None
  _LISTSERVICEINSTANCESREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSTANCEREQ.fields_by_name['application']._options = None
  _GETSERVICEINSTANCEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSTANCEREQ.fields_by_name['service']._options = None
  _GETSERVICEINSTANCEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSTANCEREQ.fields_by_name['release_channel']._options = None
  _GETSERVICEINSTANCEREQ.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEMETRICSREQ.fields_by_name['application']._options = None
  _GETSERVICEMETRICSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEMETRICSREQ.fields_by_name['service']._options = None
  _GETSERVICEMETRICSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSIGHTSREQ.fields_by_name['application']._options = None
  _GETSERVICEINSIGHTSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSIGHTSREQ.fields_by_name['service']._options = None
  _GETSERVICEINSIGHTSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _LISTCOMMITSREQ.fields_by_name['application']._options = None
  _LISTCOMMITSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTCOMMITSREQ.fields_by_name['service']._options = None
  _LISTCOMMITSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['application']._options = None
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['service']._options = None
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['class']._options = None
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['class']._serialized_options = b'\372B\005\202\001\002\020\001'
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['duration']._options = None
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['duration']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _GETSERVICEMETADATAREQ.fields_by_name['application']._options = None
  _GETSERVICEMETADATAREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEMETADATAREQ.fields_by_name['service']._options = None
  _GETSERVICEMETADATAREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SETSERVICEMETADATAREQ.fields_by_name['application']._options = None
  _SETSERVICEMETADATAREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _SETSERVICEMETADATAREQ.fields_by_name['service']._options = None
  _SETSERVICEMETADATAREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SETSERVICEMETADATAREQ.fields_by_name['metadata']._options = None
  _SETSERVICEMETADATAREQ.fields_by_name['metadata']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTMATERIALIZEDCONFIGVERSIONSREQ.fields_by_name['application']._options = None
  _LISTMATERIALIZEDCONFIGVERSIONSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTMATERIALIZEDCONFIGVERSIONSREQ.fields_by_name['service']._options = None
  _LISTMATERIALIZEDCONFIGVERSIONSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _CONFIGURESERVICEREQ.fields_by_name['application']._options = None
  _CONFIGURESERVICEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _CONFIGURESERVICEREQ.fields_by_name['service_config']._options = None
  _CONFIGURESERVICEREQ.fields_by_name['service_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTSERVICECONFIGVERSIONSREQ.fields_by_name['application']._options = None
  _LISTSERVICECONFIGVERSIONSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICECONFIGVERSIONSREQ.fields_by_name['service']._options = None
  _LISTSERVICECONFIGVERSIONSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICECONFIGREQ.fields_by_name['application']._options = None
  _GETSERVICECONFIGREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICECONFIGREQ.fields_by_name['service']._options = None
  _GETSERVICECONFIGREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SERVICEMANAGER.methods_by_name['ConfigureService']._options = None
  _SERVICEMANAGER.methods_by_name['ConfigureService']._serialized_options = b'\202\323\344\223\002,\"\'/v1/{application=*}/services/configure2:\001*'
  _SERVICEMANAGER.methods_by_name['ListServiceConfigVersions']._options = None
  _SERVICEMANAGER.methods_by_name['ListServiceConfigVersions']._serialized_options = b'\202\323\344\223\002:\0228/v1/{application=*}/services/{service=*}/config/versions'
  _SERVICEMANAGER.methods_by_name['GetServiceConfig']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceConfig']._serialized_options = b'\202\323\344\223\0021\022//v1/{application=*}/services/{service=*}/config'
  _SERVICEMANAGER.methods_by_name['ApplyParameters']._options = None
  _SERVICEMANAGER.methods_by_name['ApplyParameters']._serialized_options = b'\202\323\344\223\0022\"-/v1/{application=*}/services/apply-parameters:\001*'
  _SERVICEMANAGER.methods_by_name['ValidateApplyParameters']._options = None
  _SERVICEMANAGER.methods_by_name['ValidateApplyParameters']._serialized_options = b'\202\323\344\223\002;\"6/v1/{application=*}/services/apply-parameters/validate:\001*'
  _SERVICEMANAGER.methods_by_name['GetMaterializedConfig']._options = None
  _SERVICEMANAGER.methods_by_name['GetMaterializedConfig']._serialized_options = b'\202\323\344\223\002>\022</v1/{application=*}/services/{service=*}/materialized/config'
  _SERVICEMANAGER.methods_by_name['ListMaterializedConfigVersions']._options = None
  _SERVICEMANAGER.methods_by_name['ListMaterializedConfigVersions']._serialized_options = b'\202\323\344\223\002G\022E/v1/{application=*}/services/{service=*}/materialized/config/versions'
  _SERVICEMANAGER.methods_by_name['DeleteService']._options = None
  _SERVICEMANAGER.methods_by_name['DeleteService']._serialized_options = b'\202\323\344\223\0021*//v1/{application=*}/services/{service=*}/delete'
  _SERVICEMANAGER.methods_by_name['ListServices']._options = None
  _SERVICEMANAGER.methods_by_name['ListServices']._serialized_options = b'\202\323\344\223\002+\022)/v1/applications/{application=*}/services'
  _SERVICEMANAGER.methods_by_name['ListCommits']._options = None
  _SERVICEMANAGER.methods_by_name['ListCommits']._serialized_options = b'\202\323\344\223\002?\022=/v1/applications/{application=*}/services/{service=*}/commits'
  _SERVICEMANAGER.methods_by_name['GetService']._options = None
  _SERVICEMANAGER.methods_by_name['GetService']._serialized_options = b'\202\323\344\223\0027\0225/v1/applications/{application=*}/services/{service=*}'
  _SERVICEMANAGER.methods_by_name['ListServiceInstances']._options = None
  _SERVICEMANAGER.methods_by_name['ListServiceInstances']._serialized_options = b'\202\323\344\223\002H\022F/v1/applications/{application=*}/services/{service=*}/release-channels'
  _SERVICEMANAGER.methods_by_name['GetServiceInstance']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceInstance']._serialized_options = b'\202\323\344\223\002\\\022Z/v1/applications/{application=*}/services/{service=*}/release-channels/{release_channel=*}'
  _SERVICEMANAGER.methods_by_name['GetServiceMetrics']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceMetrics']._serialized_options = b'\202\323\344\223\002?\022=/v1/applications/{application=*}/services/{service=*}/metrics'
  _SERVICEMANAGER.methods_by_name['GetServiceInsights']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceInsights']._serialized_options = b'\202\323\344\223\002@\022>/v1/applications/{application=*}/services/{service=*}/insights'
  _SERVICEMANAGER.methods_by_name['SnoozeServiceInsight']._options = None
  _SERVICEMANAGER.methods_by_name['SnoozeServiceInsight']._serialized_options = b'\202\323\344\223\002G\032E/v1/applications/{application=*}/services/{service=*}/insights/snooze'
  _SERVICEMANAGER.methods_by_name['GetServiceMetadata']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceMetadata']._serialized_options = b'\202\323\344\223\002@\022>/v1/applications/{application=*}/services/{service=*}/metadata'
  _SERVICEMANAGER.methods_by_name['SetServiceMetadata']._options = None
  _SERVICEMANAGER.methods_by_name['SetServiceMetadata']._serialized_options = b'\202\323\344\223\002C\">/v1/applications/{application=*}/services/{service=*}/metadata:\001*'
  _SERVICECONFIGVERSIONREFERENCE._serialized_start=528
  _SERVICECONFIGVERSIONREFERENCE._serialized_end=647
  _APPLYPARAMETERSREQ._serialized_start=650
  _APPLYPARAMETERSREQ._serialized_end=1343
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL._serialized_start=1151
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL._serialized_end=1279
  _APPLYPARAMETERSRESP._serialized_start=1345
  _APPLYPARAMETERSRESP._serialized_end=1459
  _VALIDATEAPPLYPARAMETERSRESP._serialized_start=1462
  _VALIDATEAPPLYPARAMETERSRESP._serialized_end=1711
  _GETMATERIALIZEDCONFIGREQ._serialized_start=1713
  _GETMATERIALIZEDCONFIGREQ._serialized_end=1803
  _GETMATERIALIZEDCONFIGRESP._serialized_start=1806
  _GETMATERIALIZEDCONFIGRESP._serialized_end=2145
  _DELETESERVICEREQ._serialized_start=2147
  _DELETESERVICEREQ._serialized_end=2212
  _DELETESERVICERESP._serialized_start=2214
  _DELETESERVICERESP._serialized_end=2233
  _LISTSERVICESREQ._serialized_start=2235
  _LISTSERVICESREQ._serialized_end=2300
  _LISTSERVICESRESP._serialized_start=2302
  _LISTSERVICESRESP._serialized_end=2365
  _GETSERVICEREQ._serialized_start=2367
  _GETSERVICEREQ._serialized_end=2438
  _GETSERVICERESP._serialized_start=2440
  _GETSERVICERESP._serialized_end=2500
  _LISTSERVICEINSTANCESREQ._serialized_start=2502
  _LISTSERVICEINSTANCESREQ._serialized_end=2583
  _LISTSERVICEINSTANCESRESP._serialized_start=2585
  _LISTSERVICEINSTANCESRESP._serialized_end=2673
  _GETSERVICEINSTANCEREQ._serialized_start=2675
  _GETSERVICEINSTANCEREQ._serialized_end=2788
  _GETSERVICEINSTANCERESP._serialized_start=2790
  _GETSERVICEINSTANCERESP._serialized_end=2875
  _GETSERVICEMETRICSREQ._serialized_start=2878
  _GETSERVICEMETRICSREQ._serialized_end=3082
  _GETSERVICEMETRICSRESP._serialized_start=3084
  _GETSERVICEMETRICSRESP._serialized_end=3210
  _GETSERVICEINSIGHTSREQ._serialized_start=3212
  _GETSERVICEINSIGHTSREQ._serialized_end=3291
  _LISTCOMMITSREQ._serialized_start=3293
  _LISTCOMMITSREQ._serialized_end=3404
  _LISTCOMMITSRESP._serialized_start=3406
  _LISTCOMMITSRESP._serialized_end=3488
  _GETSERVICEINSIGHTSRESP._serialized_start=3490
  _GETSERVICEINSIGHTSRESP._serialized_end=3560
  _SNOOZESERVICEINSIGHTREQ._serialized_start=3563
  _SNOOZESERVICEINSIGHTREQ._serialized_end=3752
  _SNOOZESERVICEINSIGHTRESP._serialized_start=3754
  _SNOOZESERVICEINSIGHTRESP._serialized_end=3780
  _GETSERVICEMETADATAREQ._serialized_start=3782
  _GETSERVICEMETADATAREQ._serialized_end=3861
  _GETSERVICEMETADATARESP._serialized_start=3863
  _GETSERVICEMETADATARESP._serialized_end=3944
  _SETSERVICEMETADATAREQ._serialized_start=3947
  _SETSERVICEMETADATAREQ._serialized_end=4093
  _SETSERVICEMETADATARESP._serialized_start=4095
  _SETSERVICEMETADATARESP._serialized_end=4119
  _LISTMATERIALIZEDCONFIGVERSIONSREQ._serialized_start=4122
  _LISTMATERIALIZEDCONFIGVERSIONSREQ._serialized_end=4252
  _LISTMATERIALIZEDCONFIGVERSIONSRESP._serialized_start=4255
  _LISTMATERIALIZEDCONFIGVERSIONSRESP._serialized_end=4684
  _LISTMATERIALIZEDCONFIGVERSIONSRESP_VERSIONMETADATA._serialized_start=4407
  _LISTMATERIALIZEDCONFIGVERSIONSRESP_VERSIONMETADATA._serialized_end=4684
  _CONFIGURESERVICEREQ._serialized_start=4687
  _CONFIGURESERVICEREQ._serialized_end=4906
  _CONFIGURESERVICERESP._serialized_start=4908
  _CONFIGURESERVICERESP._serialized_end=4974
  _LISTSERVICECONFIGVERSIONSREQ._serialized_start=4976
  _LISTSERVICECONFIGVERSIONSREQ._serialized_end=5101
  _LISTSERVICECONFIGVERSIONSRESP._serialized_start=5104
  _LISTSERVICECONFIGVERSIONSRESP._serialized_end=5437
  _LISTSERVICECONFIGVERSIONSRESP_VERSIONMETADATA._serialized_start=5246
  _LISTSERVICECONFIGVERSIONSRESP_VERSIONMETADATA._serialized_end=5437
  _GETSERVICECONFIGREQ._serialized_start=5439
  _GETSERVICECONFIGREQ._serialized_end=5540
  _GETSERVICECONFIGRESP._serialized_start=5543
  _GETSERVICECONFIGRESP._serialized_end=5736
  _SERVICEMANAGER._serialized_start=5739
  _SERVICEMANAGER._serialized_end=8886
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.capability.capability_pb2
import prodvana.proto.prodvana.common_config.notification_pb2
import prodvana.proto.prodvana.release_channel.release_channel_config_pb2
import prodvana.proto.prodvana.template.service_pb2
import prodvana.proto.prodvana.workflow.integration_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ApplicationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RELEASE_CHANNELS_FIELD_NUMBER: builtins.int
    NOTIFICATIONS_FIELD_NUMBER: builtins.int
    ALERTS_FIELD_NUMBER: builtins.int
    CAPABILITIES_FIELD_NUMBER: builtins.int
    CAPABILITY_INSTANCES_FIELD_NUMBER: builtins.int
    SERVICE_TEMPLATES_FIELD_NUMBER: builtins.int
    ENABLE_CUSTOM_TASKS_DYNAMIC_DELIVERY_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def release_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig]: ...
    @property
    def notifications(self) -> prodvana.proto.prodvana.common_config.notification_pb2.NotificationConfig: ...
    @property
    def alerts(self) -> prodvana.proto.prodvana.workflow.integration_config_pb2.AlertingConfig: ...
    @property
    def capabilities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.capability.capability_pb2.CapabilityConfig]:
        """capabilities are dependencies that services in this applications can use"""
    @property
    def capability_instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.capability.capability_pb2.CapabilityInstanceConfig]:
        """optional capability instances that can be referenced by `capabilities`, useful to deduplication.
        for example, you may choose to have two database capability instances, staging and prod,
        and use them across release channels staging, beta, and prod, where beta and prod use the prod db.
        """
    @property
    def service_templates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.template.service_pb2.ServiceTemplate]:
        """service templates are sets of service configurations that can be used as the base of a service.
        this is useful for setting default values that are kept in sync when the templates change.
        """
    enable_custom_tasks_dynamic_delivery: builtins.bool
    """if set and use_dynamic_delivery is set, transform custom tasks to DD preconditions for all services.
    Only used for safely migrating prime capabilities to DD.
    UNUSED: Remove from proto once the flag has been removed from all persisted configs.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        release_channels: collections.abc.Iterable[prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig] | None = ...,
        notifications: prodvana.proto.prodvana.common_config.notification_pb2.NotificationConfig | None = ...,
        alerts: prodvana.proto.prodvana.workflow.integration_config_pb2.AlertingConfig | None = ...,
        capabilities: collections.abc.Iterable[prodvana.proto.prodvana.capability.capability_pb2.CapabilityConfig] | None = ...,
        capability_instances: collections.abc.Iterable[prodvana.proto.prodvana.capability.capability_pb2.CapabilityInstanceConfig] | None = ...,
        service_templates: collections.abc.Iterable[prodvana.proto.prodvana.template.service_pb2.ServiceTemplate] | None = ...,
        enable_custom_tasks_dynamic_delivery: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alerts", b"alerts", "notifications", b"notifications"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alerts", b"alerts", "capabilities", b"capabilities", "capability_instances", b"capability_instances", "enable_custom_tasks_dynamic_delivery", b"enable_custom_tasks_dynamic_delivery", "name", b"name", "notifications", b"notifications", "release_channels", b"release_channels", "service_templates", b"service_templates"]) -> None: ...

global___ApplicationConfig = ApplicationConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/template/service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.service import service_config_pb2 as prodvana_dot_service_dot_service__config__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fprodvana/template/service.proto\x12\x11prodvana.template\x1a\x1aprodvana/object/meta.proto\x1a%prodvana/service/service_config.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\xba\x01\n\x0fServiceTemplate\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x39\n\x15last_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x0eservice_config\x18\x03 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfigB\x08\xfa\x42\x05\x8a\x01\x02\x08\x01\x42MZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/templateb\x06proto3')



_SERVICETEMPLATE = DESCRIPTOR.message_types_by_name['ServiceTemplate']
ServiceTemplate = _reflection.GeneratedProtocolMessageType('ServiceTemplate', (_message.Message,), {
  'DESCRIPTOR' : _SERVICETEMPLATE,
  '__module__' : 'prodvana.template.service_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.template.ServiceTemplate)
  })
_sym_db.RegisterMessage(ServiceTemplate)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/template'
  _SERVICETEMPLATE.fields_by_name['service_config']._options = None
  _SERVICETEMPLATE.fields_by_name['service_config']._serialized_options = b'\372B\005\212\001\002\010\001'
  _SERVICETEMPLATE._serialized_start=180
  _SERVICETEMPLATE._serialized_end=366
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release_channel/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.release_channel import release_channel_config_pb2 as prodvana_dot_release__channel_dot_release__channel__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%prodvana/release_channel/object.proto\x12\x18prodvana.release_channel\x1a\x1aprodvana/object/meta.proto\x1a\x35prodvana/release_channel/release_channel_config.proto\"}\n\"ReleaseChannelProtectionAttachment\x12\x12\n\nprotection\x18\x01 \x01(\t\x12\x12\n\nattachment\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65sired_state_id\x18\x03 \x01(\t\x12\x15\n\rattachment_id\x18\x04 \x01(\t\"s\n\x13ReleaseChannelState\x12\\\n\x16protection_attachments\x18\x01 \x03(\x0b\x32<.prodvana.release_channel.ReleaseChannelProtectionAttachment\"\xb9\x01\n\x0eReleaseChannel\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12>\n\x06\x63onfig\x18\x02 \x01(\x0b\x32..prodvana.release_channel.ReleaseChannelConfig\x12<\n\x05state\x18\x03 \x01(\x0b\x32-.prodvana.release_channel.ReleaseChannelStateBTZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channelb\x06proto3')



_RELEASECHANNELPROTECTIONATTACHMENT = DESCRIPTOR.message_types_by_name['ReleaseChannelProtectionAttachment']
_RELEASECHANNELSTATE = DESCRIPTOR.message_types_by_name['ReleaseChannelState']
_RELEASECHANNEL = DESCRIPTOR.message_types_by_name['ReleaseChannel']
ReleaseChannelProtectionAttachment = _reflection.GeneratedProtocolMessageType('ReleaseChannelProtectionAttachment', (_message.Message,), {
  'DESCRIPTOR' : _RELEASECHANNELPROTECTIONATTACHMENT,
  '__module__' : 'prodvana.release_channel.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ReleaseChannelProtectionAttachment)
  })
_sym_db.RegisterMessage(ReleaseChannelProtectionAttachment)

ReleaseChannelState = _reflection.GeneratedProtocolMessageType('ReleaseChannelState', (_message.Message,), {
  'DESCRIPTOR' : _RELEASECHANNELSTATE,
  '__module__' : 'prodvana.release_channel.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ReleaseChannelState)
  })
_sym_db.RegisterMessage(ReleaseChannelState)

ReleaseChannel = _reflection.GeneratedProtocolMessageType('ReleaseChannel', (_message.Message,), {
  'DESCRIPTOR' : _RELEASECHANNEL,
  '__module__' : 'prodvana.release_channel.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ReleaseChannel)
  })
_sym_db.RegisterMessage(ReleaseChannel)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channel'
  _RELEASECHANNELPROTECTIONATTACHMENT._serialized_start=150
  _RELEASECHANNELPROTECTIONATTACHMENT._serialized_end=275
  _RELEASECHANNELSTATE._serialized_start=277
  _RELEASECHANNELSTATE._serialized_end=392
  _RELEASECHANNEL._serialized_start=395
  _RELEASECHANNEL._serialized_end=580
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/helm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.prodvana.common_config import kubernetes_config_pb2 as prodvana_dot_common__config_dot_kubernetes__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/common_config/helm.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\x1a prodvana/common_config/env.proto\x1a.prodvana/common_config/kubernetes_config.proto\"l\n\x0fRemoteHelmChart\x12\x0e\n\x04repo\x18\x01 \x01(\tH\x00\x12\x16\n\x05\x63hart\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1e\n\rchart_version\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x11\n\nrepo_oneof\x12\x03\xf8\x42\x01\"\x94\x02\n\x13HelmValuesOverrides\x12\x1a\n\x07inlined\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x34\n\x05local\x18\x02 \x01(\x0b\x32#.prodvana.common_config.LocalConfigH\x00\x12K\n\x03map\x18\x03 \x03(\x0b\x32\x34.prodvana.common_config.HelmValuesOverrides.MapEntryB\x08\xfa\x42\x05\x9a\x01\x02\x18\x01\x1aL\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\x42\x10\n\x0eoverride_oneof\"\xd4\x01\n\nHelmConfig\x12\x39\n\x06remote\x18\x01 \x01(\x0b\x32\'.prodvana.common_config.RemoteHelmChartH\x00\x12\x45\n\x10values_overrides\x18\x02 \x03(\x0b\x32+.prodvana.common_config.HelmValuesOverrides\x12\x14\n\x0crelease_name\x18\x03 \x01(\t\x12\x1a\n\tnamespace\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x18\x00\x42\x12\n\x0b\x63hart_oneof\x12\x03\xf8\x42\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')



_REMOTEHELMCHART = DESCRIPTOR.message_types_by_name['RemoteHelmChart']
_HELMVALUESOVERRIDES = DESCRIPTOR.message_types_by_name['HelmValuesOverrides']
_HELMVALUESOVERRIDES_MAPENTRY = _HELMVALUESOVERRIDES.nested_types_by_name['MapEntry']
_HELMCONFIG = DESCRIPTOR.message_types_by_name['HelmConfig']
RemoteHelmChart = _reflection.GeneratedProtocolMessageType('RemoteHelmChart', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEHELMCHART,
  '__module__' : 'prodvana.common_config.helm_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.RemoteHelmChart)
  })
_sym_db.RegisterMessage(RemoteHelmChart)

HelmValuesOverrides = _reflection.GeneratedProtocolMessageType('HelmValuesOverrides', (_message.Message,), {

  'MapEntry' : _reflection.GeneratedProtocolMessageType('MapEntry', (_message.Message,), {
    'DESCRIPTOR' : _HELMVALUESOVERRIDES_MAPENTRY,
    '__module__' : 'prodvana.common_config.helm_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.common_config.HelmValuesOverrides.MapEntry)
    })
  ,
  'DESCRIPTOR' : _HELMVALUESOVERRIDES,
  '__module__' : 'prodvana.common_config.helm_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.HelmValuesOverrides)
  })
_sym_db.RegisterMessage(HelmValuesOverrides)
_sym_db.RegisterMessage(HelmValuesOverrides.MapEntry)

HelmConfig = _reflection.GeneratedProtocolMessageType('HelmConfig', (_message.Message,), {
  'DESCRIPTOR' : _HELMCONFIG,
  '__module__' : 'prodvana.common_config.helm_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.HelmConfig)
  })
_sym_db.RegisterMessage(HelmConfig)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _REMOTEHELMCHART.oneofs_by_name['repo_oneof']._options = None
  _REMOTEHELMCHART.oneofs_by_name['repo_oneof']._serialized_options = b'\370B\001'
  _REMOTEHELMCHART.fields_by_name['chart']._options = None
  _REMOTEHELMCHART.fields_by_name['chart']._serialized_options = b'\372B\004r\002\020\001'
  _REMOTEHELMCHART.fields_by_name['chart_version']._options = None
  _REMOTEHELMCHART.fields_by_name['chart_version']._serialized_options = b'\372B\004r\002\020\001'
  _HELMVALUESOVERRIDES_MAPENTRY._options = None
  _HELMVALUESOVERRIDES_MAPENTRY._serialized_options = b'8\001'
  _HELMVALUESOVERRIDES.fields_by_name['inlined']._options = None
  _HELMVALUESOVERRIDES.fields_by_name['inlined']._serialized_options = b'\372B\004r\002\020\001'
  _HELMVALUESOVERRIDES.fields_by_name['map']._options = None
  _HELMVALUESOVERRIDES.fields_by_name['map']._serialized_options = b'\372B\005\232\001\002\030\001'
  _HELMCONFIG.oneofs_by_name['chart_oneof']._options = None
  _HELMCONFIG.oneofs_by_name['chart_oneof']._serialized_options = b'\370B\001'
  _HELMCONFIG.fields_by_name['namespace']._options = None
  _HELMCONFIG.fields_by_name['namespace']._serialized_options = b'\372B\004r\002\030\000'
  _REMOTEHELMCHART._serialized_start=168
  _REMOTEHELMCHART._serialized_end=276
  _HELMVALUESOVERRIDES._serialized_start=279
  _HELMVALUESOVERRIDES._serialized_end=555
  _HELMVALUESOVERRIDES_MAPENTRY._serialized_start=461
  _HELMVALUESOVERRIDES_MAPENTRY._serialized_end=537
  _HELMCONFIG._serialized_start=558
  _HELMCONFIG._serialized_end=770
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.protection.protection_reference_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AttachmentType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AttachmentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AttachmentType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _AttachmentType.ValueType  # 0
    RELEASE_CHANNEL: _AttachmentType.ValueType  # 1
    SERVICE_INSTANCE: _AttachmentType.ValueType  # 2
    CONVERGENCE: _AttachmentType.ValueType  # 3

class AttachmentType(_AttachmentType, metaclass=_AttachmentTypeEnumTypeWrapper): ...

UNKNOWN: AttachmentType.ValueType  # 0
RELEASE_CHANNEL: AttachmentType.ValueType  # 1
SERVICE_INSTANCE: AttachmentType.ValueType  # 2
CONVERGENCE: AttachmentType.ValueType  # 3
global___AttachmentType = AttachmentType

class ProtectionConvergenceAttachment(google.protobuf.message.Message):
    """Protections attached to convergence. The desired state ID of the convergence is passed to the protection
    and its lifecycle is tied to the convergence itself.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    REF_FIELD_NUMBER: builtins.int
    LIFECYCLE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """optional, default to protection name"""
    @property
    def ref(self) -> prodvana.proto.prodvana.protection.protection_reference_pb2.ProtectionReference: ...
    @property
    def lifecycle(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.protection_reference_pb2.ProtectionLifecycle]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        ref: prodvana.proto.prodvana.protection.protection_reference_pb2.ProtectionReference | None = ...,
        lifecycle: collections.abc.Iterable[prodvana.proto.prodvana.protection.protection_reference_pb2.ProtectionLifecycle] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ref", b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lifecycle", b"lifecycle", "name", b"name", "ref", b"ref"]) -> None: ...

global___ProtectionConvergenceAttachment = ProtectionConvergenceAttachment



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/environment/clusters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.prodvana.common_config import task_pb2 as prodvana_dot_common__config_dot_task__pb2
from prodvana.proto.prodvana.common_config import kubernetes_config_pb2 as prodvana_dot_common__config_dot_kubernetes__config__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2
from prodvana.proto.prodvana.runtimes import runtimes_config_pb2 as prodvana_dot_runtimes_dot_runtimes__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#prodvana/environment/clusters.proto\x12\x14prodvana.environment\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a prodvana/common_config/env.proto\x1a!prodvana/common_config/task.proto\x1a.prodvana/common_config/kubernetes_config.proto\x1a\'prodvana/common_config/parameters.proto\x1a\'prodvana/runtimes/runtimes_config.proto\"\xfd\x03\n\x0b\x43lusterAuth\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61_cert\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\x12\x17\n\x0fservice_account\x18\x04 \x01(\t\x12\x38\n\x03\x65\x63s\x18\x05 \x01(\x0b\x32).prodvana.environment.ClusterAuth.ECSAuthH\x00\x12\x38\n\x03k8s\x18\x08 \x01(\x0b\x32).prodvana.environment.ClusterAuth.K8sAuthH\x00\x12\x16\n\x0ek8s_agent_auth\x18\x06 \x01(\x08\x1ao\n\x07\x45\x43SAuth\x12\x12\n\naccess_key\x18\x01 \x01(\t\x12\x12\n\nsecret_key\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x17\n\x0f\x61ssume_role_arn\x18\x04 \x01(\t\x12\x13\n\x0b\x63luster_arn\x18\x05 \x01(\t\x1a\x86\x01\n\x07K8sAuth\x12J\n\tagent_env\x18\x01 \x03(\x0b\x32\x37.prodvana.environment.ClusterAuth.K8sAuth.AgentEnvEntry\x1a/\n\rAgentEnvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\nauth_oneofJ\x04\x08\x07\x10\x08R\textension\"\xe9\x02\n\x07\x43luster\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x34\n\x06origin\x18\x03 \x01(\x0e\x32$.prodvana.environment.Cluster.Origin\x12/\n\x04\x61uth\x18\x04 \x01(\x0b\x32!.prodvana.environment.ClusterAuth\x12/\n\x04type\x18\x05 \x01(\x0e\x32!.prodvana.environment.ClusterType\x12\x33\n\x06\x63onfig\x18\x06 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12<\n\x18last_heartbeat_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x06Origin\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08PRODVANA\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\xc6\x01\n\x11\x46\x61keClusterConfig\x12Z\n\x11\x63rashing_programs\x18\x01 \x03(\x0b\x32?.prodvana.environment.FakeClusterConfig.CrashingProgramPatterns\x1aU\n\x17\x43rashingProgramPatterns\x12\x13\n\x0bimage_regex\x18\x01 \x01(\t\x12\x11\n\tcmd_regex\x18\x02 \x01(\t\x12\x12\n\nlog_output\x18\x03 \x01(\t\"\x86\x02\n\x10\x45xtensionCommand\x12\x39\n\x0btask_config\x18\x01 \x01(\x0b\x32\".prodvana.common_config.TaskConfigH\x00\x12\x45\n\x11kubernetes_config\x18\x02 \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x12\x30\n\rpoll_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12*\n\x07timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x12\n\x0b\x65xec_config\x12\x03\xf8\x42\x01\"\xac\x02\n\x16\x45xtensionClusterConfig\x12?\n\x05\x61pply\x18\x01 \x01(\x0b\x32&.prodvana.environment.ExtensionCommandB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x35\n\x05\x66\x65tch\x18\x02 \x01(\x0b\x32&.prodvana.environment.ExtensionCommand\x12N\n\nparameters\x18\x03 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinitionB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12J\n\rproxy_runtime\x18\x04 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xc2\x02\n\x18\x43ompiledExtensionCommand\x12\x13\n\x0bname_prefix\x18\x01 \x01(\t\x12\x37\n\x07\x63ommand\x18\x02 \x01(\x0b\x32&.prodvana.environment.ExtensionCommand\x12\x44\n\x11runtime_execution\x18\x03 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfig\x12\x44\n\x03\x65nv\x18\x04 \x03(\x0b\x32\x37.prodvana.environment.CompiledExtensionCommand.EnvEntry\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\"\xc0\x0c\n\rClusterConfig\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x17\n\x0f\x64isable_flagger\x18\x01 \x01(\x08\x12\x15\n\rdisable_istio\x18\x02 \x01(\x08\x12>\n\x08kubecost\x18\x03 \x01(\x0b\x32,.prodvana.environment.ClusterConfig.Kubecost\x12<\n\x07\x64\x61tadog\x18\x04 \x01(\x0b\x32+.prodvana.environment.ClusterConfig.Datadog\x12\x43\n\x0b\x61lb_ingress\x18\x06 \x01(\x0b\x32..prodvana.environment.ClusterConfig.ALBIngress\x12G\n\rargo_rollouts\x18\x07 \x01(\x0b\x32\x30.prodvana.environment.ClusterConfig.ArgoRollouts\x12\x43\n\x0bgke_ingress\x18\x08 \x01(\x0b\x32..prodvana.environment.ClusterConfig.GKEIngress\x12P\n\x18self_managed_gke_ingress\x18\x0b \x01(\x0b\x32..prodvana.environment.ClusterConfig.GKEIngress\x12I\n\x0e\x63loud_provider\x18\t \x01(\x0e\x32\x31.prodvana.environment.ClusterConfig.CloudProvider\x12\x37\n\x04\x66\x61ke\x18\n \x01(\x0b\x32\'.prodvana.environment.FakeClusterConfigH\x00\x12\x41\n\textension\x18\x0c \x01(\x0b\x32,.prodvana.environment.ExtensionClusterConfigH\x00\x1aH\n\x08Kubecost\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07managed\x18\x02 \x01(\x08\x12\x1a\n\x12kubecost_namespace\x18\x03 \x01(\t\x1a\x65\n\x07\x44\x61tadog\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07managed\x18\x02 \x01(\x08\x12\x19\n\x11\x64\x61tadog_namespace\x18\x03 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x0c\n\x04site\x18\x05 \x01(\t\x1a\x62\n\nALBIngress\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1e\n\ringress_class\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12#\n\x1b\x64\x65\x66\x61ult_balancer_attributes\x18\x03 \x03(\t\x1a\xba\x03\n\x0c\x41rgoRollouts\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12T\n\ttemplates\x18\x02 \x03(\x0b\x32\x41.prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate\x1a\xc2\x02\n\x10\x41nalysisTemplate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x66\n\x0b\x61rg_mapping\x18\x02 \x03(\x0b\x32Q.prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgMappingEntry\x1a}\n\x0f\x41rgMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12Y\n\x05value\x18\x02 \x01(\x0e\x32J.prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue:\x02\x38\x01\"9\n\x08\x41rgValue\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVICE\x10\x01\x12\x13\n\x0fRELEASE_CHANNEL\x10\x02\x1a\x37\n\nGKEIngress\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x18\n\x10\x63ontainer_native\x18\x02 \x01(\x08\"T\n\rCloudProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x45KS\x10\x01\x12\x07\n\x03GKE\x10\x02\x12\x07\n\x03\x41KS\x10\x03\x12\n\n\x06ONPREM\x10\x04\x12\x0f\n\x0bOTHER_CLOUD\x10\x05\x42\x0f\n\rcluster_oneofJ\x04\x08\x05\x10\x06R\x0f\x61ws_alb_ingress*E\n\x0b\x43lusterType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03K8S\x10\x01\x12\x07\n\x03\x45\x43S\x10\x02\x12\x08\n\x04\x46\x41KE\x10\x03\x12\r\n\tEXTENSION\x10\x04\x42PZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environmentb\x06proto3')

_CLUSTERTYPE = DESCRIPTOR.enum_types_by_name['ClusterType']
ClusterType = enum_type_wrapper.EnumTypeWrapper(_CLUSTERTYPE)
UNKNOWN = 0
K8S = 1
ECS = 2
FAKE = 3
EXTENSION = 4


_CLUSTERAUTH = DESCRIPTOR.message_types_by_name['ClusterAuth']
_CLUSTERAUTH_ECSAUTH = _CLUSTERAUTH.nested_types_by_name['ECSAuth']
_CLUSTERAUTH_K8SAUTH = _CLUSTERAUTH.nested_types_by_name['K8sAuth']
_CLUSTERAUTH_K8SAUTH_AGENTENVENTRY = _CLUSTERAUTH_K8SAUTH.nested_types_by_name['AgentEnvEntry']
_CLUSTER = DESCRIPTOR.message_types_by_name['Cluster']
_FAKECLUSTERCONFIG = DESCRIPTOR.message_types_by_name['FakeClusterConfig']
_FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS = _FAKECLUSTERCONFIG.nested_types_by_name['CrashingProgramPatterns']
_EXTENSIONCOMMAND = DESCRIPTOR.message_types_by_name['ExtensionCommand']
_EXTENSIONCLUSTERCONFIG = DESCRIPTOR.message_types_by_name['ExtensionClusterConfig']
_COMPILEDEXTENSIONCOMMAND = DESCRIPTOR.message_types_by_name['CompiledExtensionCommand']
_COMPILEDEXTENSIONCOMMAND_ENVENTRY = _COMPILEDEXTENSIONCOMMAND.nested_types_by_name['EnvEntry']
_CLUSTERCONFIG = DESCRIPTOR.message_types_by_name['ClusterConfig']
_CLUSTERCONFIG_KUBECOST = _CLUSTERCONFIG.nested_types_by_name['Kubecost']
_CLUSTERCONFIG_DATADOG = _CLUSTERCONFIG.nested_types_by_name['Datadog']
_CLUSTERCONFIG_ALBINGRESS = _CLUSTERCONFIG.nested_types_by_name['ALBIngress']
_CLUSTERCONFIG_ARGOROLLOUTS = _CLUSTERCONFIG.nested_types_by_name['ArgoRollouts']
_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE = _CLUSTERCONFIG_ARGOROLLOUTS.nested_types_by_name['AnalysisTemplate']
_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY = _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE.nested_types_by_name['ArgMappingEntry']
_CLUSTERCONFIG_GKEINGRESS = _CLUSTERCONFIG.nested_types_by_name['GKEIngress']
_CLUSTER_ORIGIN = _CLUSTER.enum_types_by_name['Origin']
_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGVALUE = _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE.enum_types_by_name['ArgValue']
_CLUSTERCONFIG_CLOUDPROVIDER = _CLUSTERCONFIG.enum_types_by_name['CloudProvider']
ClusterAuth = _reflection.GeneratedProtocolMessageType('ClusterAuth', (_message.Message,), {

  'ECSAuth' : _reflection.GeneratedProtocolMessageType('ECSAuth', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERAUTH_ECSAUTH,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth.ECSAuth)
    })
  ,

  'K8sAuth' : _reflection.GeneratedProtocolMessageType('K8sAuth', (_message.Message,), {

    'AgentEnvEntry' : _reflection.GeneratedProtocolMessageType('AgentEnvEntry', (_message.Message,), {
      'DESCRIPTOR' : _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY,
      '__module__' : 'prodvana.environment.clusters_pb2'
      # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth.K8sAuth.AgentEnvEntry)
      })
    ,
    'DESCRIPTOR' : _CLUSTERAUTH_K8SAUTH,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth.K8sAuth)
    })
  ,
  'DESCRIPTOR' : _CLUSTERAUTH,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth)
  })
_sym_db.RegisterMessage(ClusterAuth)
_sym_db.RegisterMessage(ClusterAuth.ECSAuth)
_sym_db.RegisterMessage(ClusterAuth.K8sAuth)
_sym_db.RegisterMessage(ClusterAuth.K8sAuth.AgentEnvEntry)

Cluster = _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTER,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.Cluster)
  })
_sym_db.RegisterMessage(Cluster)

FakeClusterConfig = _reflection.GeneratedProtocolMessageType('FakeClusterConfig', (_message.Message,), {

  'CrashingProgramPatterns' : _reflection.GeneratedProtocolMessageType('CrashingProgramPatterns', (_message.Message,), {
    'DESCRIPTOR' : _FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.FakeClusterConfig.CrashingProgramPatterns)
    })
  ,
  'DESCRIPTOR' : _FAKECLUSTERCONFIG,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.FakeClusterConfig)
  })
_sym_db.RegisterMessage(FakeClusterConfig)
_sym_db.RegisterMessage(FakeClusterConfig.CrashingProgramPatterns)

ExtensionCommand = _reflection.GeneratedProtocolMessageType('ExtensionCommand', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONCOMMAND,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ExtensionCommand)
  })
_sym_db.RegisterMessage(ExtensionCommand)

ExtensionClusterConfig = _reflection.GeneratedProtocolMessageType('ExtensionClusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONCLUSTERCONFIG,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ExtensionClusterConfig)
  })
_sym_db.RegisterMessage(ExtensionClusterConfig)

CompiledExtensionCommand = _reflection.GeneratedProtocolMessageType('CompiledExtensionCommand', (_message.Message,), {

  'EnvEntry' : _reflection.GeneratedProtocolMessageType('EnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMPILEDEXTENSIONCOMMAND_ENVENTRY,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.CompiledExtensionCommand.EnvEntry)
    })
  ,
  'DESCRIPTOR' : _COMPILEDEXTENSIONCOMMAND,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.CompiledExtensionCommand)
  })
_sym_db.RegisterMessage(CompiledExtensionCommand)
_sym_db.RegisterMessage(CompiledExtensionCommand.EnvEntry)

ClusterConfig = _reflection.GeneratedProtocolMessageType('ClusterConfig', (_message.Message,), {

  'Kubecost' : _reflection.GeneratedProtocolMessageType('Kubecost', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERCONFIG_KUBECOST,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.Kubecost)
    })
  ,

  'Datadog' : _reflection.GeneratedProtocolMessageType('Datadog', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERCONFIG_DATADOG,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.Datadog)
    })
  ,

  'ALBIngress' : _reflection.GeneratedProtocolMessageType('ALBIngress', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERCONFIG_ALBINGRESS,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.ALBIngress)
    })
  ,

  'ArgoRollouts' : _reflection.GeneratedProtocolMessageType('ArgoRollouts', (_message.Message,), {

    'AnalysisTemplate' : _reflection.GeneratedProtocolMessageType('AnalysisTemplate', (_message.Message,), {

      'ArgMappingEntry' : _reflection.GeneratedProtocolMessageType('ArgMappingEntry', (_message.Message,), {
        'DESCRIPTOR' : _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY,
        '__module__' : 'prodvana.environment.clusters_pb2'
        # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgMappingEntry)
        })
      ,
      'DESCRIPTOR' : _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE,
      '__module__' : 'prodvana.environment.clusters_pb2'
      # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate)
      })
    ,
    'DESCRIPTOR' : _CLUSTERCONFIG_ARGOROLLOUTS,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.ArgoRollouts)
    })
  ,

  'GKEIngress' : _reflection.GeneratedProtocolMessageType('GKEIngress', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERCONFIG_GKEINGRESS,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.GKEIngress)
    })
  ,
  'DESCRIPTOR' : _CLUSTERCONFIG,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig)
  })
_sym_db.RegisterMessage(ClusterConfig)
_sym_db.RegisterMessage(ClusterConfig.Kubecost)
_sym_db.RegisterMessage(ClusterConfig.Datadog)
_sym_db.RegisterMessage(ClusterConfig.ALBIngress)
_sym_db.RegisterMessage(ClusterConfig.ArgoRollouts)
_sym_db.RegisterMessage(ClusterConfig.ArgoRollouts.AnalysisTemplate)
_sym_db.RegisterMessage(ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgMappingEntry)
_sym_db.RegisterMessage(ClusterConfig.GKEIngress)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environment'
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._options = None
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._serialized_options = b'8\001'
  _EXTENSIONCOMMAND.oneofs_by_name['exec_config']._options = None
  _EXTENSIONCOMMAND.oneofs_by_name['exec_config']._serialized_options = b'\370B\001'
  _EXTENSIONCLUSTERCONFIG.fields_by_name['apply']._options = None
  _EXTENSIONCLUSTERCONFIG.fields_by_name['apply']._serialized_options = b'\372B\005\212\001\002\020\001'
  _EXTENSIONCLUSTERCONFIG.fields_by_name['parameters']._options = None
  _EXTENSIONCLUSTERCONFIG.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _EXTENSIONCLUSTERCONFIG.fields_by_name['proxy_runtime']._options = None
  _EXTENSIONCLUSTERCONFIG.fields_by_name['proxy_runtime']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMPILEDEXTENSIONCOMMAND_ENVENTRY._options = None
  _COMPILEDEXTENSIONCOMMAND_ENVENTRY._serialized_options = b'8\001'
  _CLUSTERCONFIG_ALBINGRESS.fields_by_name['ingress_class']._options = None
  _CLUSTERCONFIG_ALBINGRESS.fields_by_name['ingress_class']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._options = None
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._serialized_options = b'8\001'
  _CLUSTERTYPE._serialized_start=3923
  _CLUSTERTYPE._serialized_end=3992
  _CLUSTERAUTH._serialized_start=351
  _CLUSTERAUTH._serialized_end=860
  _CLUSTERAUTH_ECSAUTH._serialized_start=581
  _CLUSTERAUTH_ECSAUTH._serialized_end=692
  _CLUSTERAUTH_K8SAUTH._serialized_start=695
  _CLUSTERAUTH_K8SAUTH._serialized_end=829
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._serialized_start=782
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._serialized_end=829
  _CLUSTER._serialized_start=863
  _CLUSTER._serialized_end=1224
  _CLUSTER_ORIGIN._serialized_start=1175
  _CLUSTER_ORIGIN._serialized_end=1224
  _FAKECLUSTERCONFIG._serialized_start=1227
  _FAKECLUSTERCONFIG._serialized_end=1425
  _FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS._serialized_start=1340
  _FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS._serialized_end=1425
  _EXTENSIONCOMMAND._serialized_start=1428
  _EXTENSIONCOMMAND._serialized_end=1690
  _EXTENSIONCLUSTERCONFIG._serialized_start=1693
  _EXTENSIONCLUSTERCONFIG._serialized_end=1993
  _COMPILEDEXTENSIONCOMMAND._serialized_start=1996
  _COMPILEDEXTENSIONCOMMAND._serialized_end=2318
  _COMPILEDEXTENSIONCOMMAND_ENVENTRY._serialized_start=2242
  _COMPILEDEXTENSIONCOMMAND_ENVENTRY._serialized_end=2318
  _CLUSTERCONFIG._serialized_start=2321
  _CLUSTERCONFIG._serialized_end=3921
  _CLUSTERCONFIG_KUBECOST._serialized_start=3018
  _CLUSTERCONFIG_KUBECOST._serialized_end=3090
  _CLUSTERCONFIG_DATADOG._serialized_start=3092
  _CLUSTERCONFIG_DATADOG._serialized_end=3193
  _CLUSTERCONFIG_ALBINGRESS._serialized_start=3195
  _CLUSTERCONFIG_ALBINGRESS._serialized_end=3293
  _CLUSTERCONFIG_ARGOROLLOUTS._serialized_start=3296
  _CLUSTERCONFIG_ARGOROLLOUTS._serialized_end=3738
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE._serialized_start=3416
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE._serialized_end=3738
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._serialized_start=3554
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._serialized_end=3679
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGVALUE._serialized_start=3681
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGVALUE._serialized_end=3738
  _CLUSTERCONFIG_GKEINGRESS._serialized_start=3740
  _CLUSTERCONFIG_GKEINGRESS._serialized_end=3795
  _CLUSTERCONFIG_CLOUDPROVIDER._serialized_start=3797
  _CLUSTERCONFIG_CLOUDPROVIDER._serialized_end=3881
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/environment/environment_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.environment import clusters_pb2 as prodvana_dot_environment_dot_clusters__pb2
from prodvana.proto.prodvana.config_writeback import writeback_pb2 as prodvana_dot_config__writeback_dot_writeback__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.prodvana/environment/environment_manager.proto\x12\x14prodvana.environment\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a#prodvana/environment/clusters.proto\x1a)prodvana/config_writeback/writeback.proto\x1a&prodvana/version/source_metadata.proto\"\xaf\x02\n\x0eLinkClusterReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04\x61uth\x18\x02 \x01(\x0b\x32!.prodvana.environment.ClusterAuth\x12\x18\n\x10prodvana_managed\x18\x03 \x01(\x08\x12\x15\n\rdisable_istio\x18\x04 \x01(\x08\x12\x17\n\x0f\x64isable_flagger\x18\x05 \x01(\x08\x12/\n\x04type\x18\x06 \x01(\x0e\x32!.prodvana.environment.ClusterType\x12(\n\x06source\x18\x07 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x08 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"Z\n\x0fLinkClusterResp\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x15\n\rk8s_agent_url\x18\x04 \x01(\t\" \n\x10RemoveClusterReq\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x13\n\x11RemoveClusterResp\"\'\n\x11GetClusterAuthReq\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"E\n\x12GetClusterAuthResp\x12/\n\x04\x61uth\x18\x01 \x01(\x0b\x32!.prodvana.environment.ClusterAuth\"\x11\n\x0fListClustersReq\"\x9f\x04\n\x10ListClustersResp\x12\x44\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x32.prodvana.environment.ListClustersResp.ClusterInfo\x1a\xc4\x03\n\x0b\x43lusterInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x34\n\x06origin\x18\x03 \x01(\x0e\x32$.prodvana.environment.Cluster.Origin\x12\x10\n\x08\x65ndpoint\x18\x04 \x01(\t\x12\x17\n\x0fservice_account\x18\x05 \x01(\t\x12H\n\x10writeback_config\x18\x06 \x01(\x0b\x32..prodvana.config_writeback.ConfigWritebackPath\x12/\n\x04type\x18\x07 \x01(\x0e\x32!.prodvana.environment.ClusterType\x12I\n\x03\x65\x63s\x18\x08 \x01(\x0b\x32:.prodvana.environment.ListClustersResp.ClusterInfo.EcsInfoH\x00\x12<\n\x18last_heartbeat_timestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a.\n\x07\x45\x63sInfo\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x13\n\x0b\x63luster_arn\x18\x02 \x01(\tB\x06\n\x04info\"\xc5\x01\n\x13\x43onfigureClusterReq\x12\x14\n\x0cruntime_name\x18\x01 \x01(\t\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"\x16\n\x14\x43onfigureClusterResp\"\x1e\n\x1cValidateConfigureClusterResp\"+\n\x13GetClusterConfigReq\x12\x14\n\x0cruntime_name\x18\x01 \x01(\t\"K\n\x14GetClusterConfigResp\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\".\n\x16\x44\x65tectClusterConfigReq\x12\x14\n\x0cruntime_name\x18\x01 \x01(\t\"N\n\x17\x44\x65tectClusterConfigResp\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\")\n\x13GetClusterStatusReq\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"T\n\x14GetClusterStatusResp\x12<\n\x18last_heartbeat_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\x9e\n\n\x12\x45nvironmentManager\x12x\n\x0bLinkCluster\x12$.prodvana.environment.LinkClusterReq\x1a%.prodvana.environment.LinkClusterResp\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/clusters/link:\x01*\x12x\n\x0cListClusters\x12%.prodvana.environment.ListClustersReq\x1a&.prodvana.environment.ListClustersResp\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/clusters/list\x12\x80\x01\n\rRemoveCluster\x12&.prodvana.environment.RemoveClusterReq\x1a\'.prodvana.environment.RemoveClusterResp\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/clusters/remove:\x01*\x12\x82\x01\n\x0eGetClusterAuth\x12\'.prodvana.environment.GetClusterAuthReq\x1a(.prodvana.environment.GetClusterAuthResp\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/clusters/get_auth\x12\x9a\x01\n\x10GetClusterConfig\x12).prodvana.environment.GetClusterConfigReq\x1a*.prodvana.environment.GetClusterConfigResp\"/\x82\xd3\xe4\x93\x02)\"$/v1/clusters/{runtime_name=*}/config:\x01*\x12\xaa\x01\n\x13\x44\x65tectClusterConfig\x12,.prodvana.environment.DetectClusterConfigReq\x1a-.prodvana.environment.DetectClusterConfigResp\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/clusters/{runtime_name=*}/detect-config:\x01*\x12\x8c\x01\n\x10\x43onfigureCluster\x12).prodvana.environment.ConfigureClusterReq\x1a*.prodvana.environment.ConfigureClusterResp\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v1/clusters/configure:\x01*\x12\xa5\x01\n\x18ValidateConfigureCluster\x12).prodvana.environment.ConfigureClusterReq\x1a\x32.prodvana.environment.ValidateConfigureClusterResp\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/clusters/configure/validate:\x01*\x12\x8a\x01\n\x10GetClusterStatus\x12).prodvana.environment.GetClusterStatusReq\x1a*.prodvana.environment.GetClusterStatusResp\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/clusters/get_statusBPZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environmentb\x06proto3')



_LINKCLUSTERREQ = DESCRIPTOR.message_types_by_name['LinkClusterReq']
_LINKCLUSTERRESP = DESCRIPTOR.message_types_by_name['LinkClusterResp']
_REMOVECLUSTERREQ = DESCRIPTOR.message_types_by_name['RemoveClusterReq']
_REMOVECLUSTERRESP = DESCRIPTOR.message_types_by_name['RemoveClusterResp']
_GETCLUSTERAUTHREQ = DESCRIPTOR.message_types_by_name['GetClusterAuthReq']
_GETCLUSTERAUTHRESP = DESCRIPTOR.message_types_by_name['GetClusterAuthResp']
_LISTCLUSTERSREQ = DESCRIPTOR.message_types_by_name['ListClustersReq']
_LISTCLUSTERSRESP = DESCRIPTOR.message_types_by_name['ListClustersResp']
_LISTCLUSTERSRESP_CLUSTERINFO = _LISTCLUSTERSRESP.nested_types_by_name['ClusterInfo']
_LISTCLUSTERSRESP_CLUSTERINFO_ECSINFO = _LISTCLUSTERSRESP_CLUSTERINFO.nested_types_by_name['EcsInfo']
_CONFIGURECLUSTERREQ = DESCRIPTOR.message_types_by_name['ConfigureClusterReq']
_CONFIGURECLUSTERRESP = DESCRIPTOR.message_types_by_name['ConfigureClusterResp']
_VALIDATECONFIGURECLUSTERRESP = DESCRIPTOR.message_types_by_name['ValidateConfigureClusterResp']
_GETCLUSTERCONFIGREQ = DESCRIPTOR.message_types_by_name['GetClusterConfigReq']
_GETCLUSTERCONFIGRESP = DESCRIPTOR.message_types_by_name['GetClusterConfigResp']
_DETECTCLUSTERCONFIGREQ = DESCRIPTOR.message_types_by_name['DetectClusterConfigReq']
_DETECTCLUSTERCONFIGRESP = DESCRIPTOR.message_types_by_name['DetectClusterConfigResp']
_GETCLUSTERSTATUSREQ = DESCRIPTOR.message_types_by_name['GetClusterStatusReq']
_GETCLUSTERSTATUSRESP = DESCRIPTOR.message_types_by_name['GetClusterStatusResp']
LinkClusterReq = _reflection.GeneratedProtocolMessageType('LinkClusterReq', (_message.Message,), {
  'DESCRIPTOR' : _LINKCLUSTERREQ,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.LinkClusterReq)
  })
_sym_db.RegisterMessage(LinkClusterReq)

LinkClusterResp = _reflection.GeneratedProtocolMessageType('LinkClusterResp', (_message.Message,), {
  'DESCRIPTOR' : _LINKCLUSTERRESP,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.LinkClusterResp)
  })
_sym_db.RegisterMessage(LinkClusterResp)

RemoveClusterReq = _reflection.GeneratedProtocolMessageType('RemoveClusterReq', (_message.Message,), {
  'DESCRIPTOR' : _REMOVECLUSTERREQ,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.RemoveClusterReq)
  })
_sym_db.RegisterMessage(RemoveClusterReq)

RemoveClusterResp = _reflection.GeneratedProtocolMessageType('RemoveClusterResp', (_message.Message,), {
  'DESCRIPTOR' : _REMOVECLUSTERRESP,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.RemoveClusterResp)
  })
_sym_db.RegisterMessage(RemoveClusterResp)

GetClusterAuthReq = _reflection.GeneratedProtocolMessageType('GetClusterAuthReq', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERAUTHREQ,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.GetClusterAuthReq)
  })
_sym_db.RegisterMessage(GetClusterAuthReq)

GetClusterAuthResp = _reflection.GeneratedProtocolMessageType('GetClusterAuthResp', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERAUTHRESP,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.GetClusterAuthResp)
  })
_sym_db.RegisterMessage(GetClusterAuthResp)

ListClustersReq = _reflection.GeneratedProtocolMessageType('ListClustersReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSREQ,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ListClustersReq)
  })
_sym_db.RegisterMessage(ListClustersReq)

ListClustersResp = _reflection.GeneratedProtocolMessageType('ListClustersResp', (_message.Message,), {

  'ClusterInfo' : _reflection.GeneratedProtocolMessageType('ClusterInfo', (_message.Message,), {

    'EcsInfo' : _reflection.GeneratedProtocolMessageType('EcsInfo', (_message.Message,), {
      'DESCRIPTOR' : _LISTCLUSTERSRESP_CLUSTERINFO_ECSINFO,
      '__module__' : 'prodvana.environment.environment_manager_pb2'
      # @@protoc_insertion_point(class_scope:prodvana.environment.ListClustersResp.ClusterInfo.EcsInfo)
      })
    ,
    'DESCRIPTOR' : _LISTCLUSTERSRESP_CLUSTERINFO,
    '__module__' : 'prodvana.environment.environment_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ListClustersResp.ClusterInfo)
    })
  ,
  'DESCRIPTOR' : _LISTCLUSTERSRESP,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ListClustersResp)
  })
_sym_db.RegisterMessage(ListClustersResp)
_sym_db.RegisterMessage(ListClustersResp.ClusterInfo)
_sym_db.RegisterMessage(ListClustersResp.ClusterInfo.EcsInfo)

ConfigureClusterReq = _reflection.GeneratedProtocolMessageType('ConfigureClusterReq', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURECLUSTERREQ,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ConfigureClusterReq)
  })
_sym_db.RegisterMessage(ConfigureClusterReq)

ConfigureClusterResp = _reflection.GeneratedProtocolMessageType('ConfigureClusterResp', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURECLUSTERRESP,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ConfigureClusterResp)
  })
_sym_db.RegisterMessage(ConfigureClusterResp)

ValidateConfigureClusterResp = _reflection.GeneratedProtocolMessageType('ValidateConfigureClusterResp', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATECONFIGURECLUSTERRESP,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ValidateConfigureClusterResp)
  })
_sym_db.RegisterMessage(ValidateConfigureClusterResp)

GetClusterConfigReq = _reflection.GeneratedProtocolMessageType('GetClusterConfigReq', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERCONFIGREQ,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.GetClusterConfigReq)
  })
_sym_db.RegisterMessage(GetClusterConfigReq)

GetClusterConfigResp = _reflection.GeneratedProtocolMessageType('GetClusterConfigResp', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERCONFIGRESP,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.GetClusterConfigResp)
  })
_sym_db.RegisterMessage(GetClusterConfigResp)

DetectClusterConfigReq = _reflection.GeneratedProtocolMessageType('DetectClusterConfigReq', (_message.Message,), {
  'DESCRIPTOR' : _DETECTCLUSTERCONFIGREQ,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.DetectClusterConfigReq)
  })
_sym_db.RegisterMessage(DetectClusterConfigReq)

DetectClusterConfigResp = _reflection.GeneratedProtocolMessageType('DetectClusterConfigResp', (_message.Message,), {
  'DESCRIPTOR' : _DETECTCLUSTERCONFIGRESP,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.DetectClusterConfigResp)
  })
_sym_db.RegisterMessage(DetectClusterConfigResp)

GetClusterStatusReq = _reflection.GeneratedProtocolMessageType('GetClusterStatusReq', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERSTATUSREQ,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.GetClusterStatusReq)
  })
_sym_db.RegisterMessage(GetClusterStatusReq)

GetClusterStatusResp = _reflection.GeneratedProtocolMessageType('GetClusterStatusResp', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERSTATUSRESP,
  '__module__' : 'prodvana.environment.environment_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.GetClusterStatusResp)
  })
_sym_db.RegisterMessage(GetClusterStatusResp)

_ENVIRONMENTMANAGER = DESCRIPTOR.services_by_name['EnvironmentManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environment'
  _ENVIRONMENTMANAGER.methods_by_name['LinkCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['LinkCluster']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/clusters/link:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['ListClusters']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['ListClusters']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/clusters/list'
  _ENVIRONMENTMANAGER.methods_by_name['RemoveCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['RemoveCluster']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/clusters/remove:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterAuth']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterAuth']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/clusters/get_auth'
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterConfig']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterConfig']._serialized_options = b'\202\323\344\223\002)\"$/v1/clusters/{runtime_name=*}/config:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['DetectClusterConfig']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['DetectClusterConfig']._serialized_options = b'\202\323\344\223\0020\"+/v1/clusters/{runtime_name=*}/detect-config:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['ConfigureCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['ConfigureCluster']._serialized_options = b'\202\323\344\223\002\033\"\026/v1/clusters/configure:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['ValidateConfigureCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['ValidateConfigureCluster']._serialized_options = b'\202\323\344\223\002$\"\037/v1/clusters/configure/validate:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterStatus']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterStatus']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/clusters/get_status'
  _LINKCLUSTERREQ._serialized_start=256
  _LINKCLUSTERREQ._serialized_end=559
  _LINKCLUSTERRESP._serialized_start=561
  _LINKCLUSTERRESP._serialized_end=651
  _REMOVECLUSTERREQ._serialized_start=653
  _REMOVECLUSTERREQ._serialized_end=685
  _REMOVECLUSTERRESP._serialized_start=687
  _REMOVECLUSTERRESP._serialized_end=706
  _GETCLUSTERAUTHREQ._serialized_start=708
  _GETCLUSTERAUTHREQ._serialized_end=747
  _GETCLUSTERAUTHRESP._serialized_start=749
  _GETCLUSTERAUTHRESP._serialized_end=818
  _LISTCLUSTERSREQ._serialized_start=820
  _LISTCLUSTERSREQ._serialized_end=837
  _LISTCLUSTERSRESP._serialized_start=840
  _LISTCLUSTERSRESP._serialized_end=1383
  _LISTCLUSTERSRESP_CLUSTERINFO._serialized_start=931
  _LISTCLUSTERSRESP_CLUSTERINFO._serialized_end=1383
  _LISTCLUSTERSRESP_CLUSTERINFO_ECSINFO._serialized_start=1329
  _LISTCLUSTERSRESP_CLUSTERINFO_ECSINFO._serialized_end=1375
  _CONFIGURECLUSTERREQ._serialized_start=1386
  _CONFIGURECLUSTERREQ._serialized_end=1583
  _CONFIGURECLUSTERRESP._serialized_start=1585
  _CONFIGURECLUSTERRESP._serialized_end=1607
  _VALIDATECONFIGURECLUSTERRESP._serialized_start=1609
  _VALIDATECONFIGURECLUSTERRESP._serialized_end=1639
  _GETCLUSTERCONFIGREQ._serialized_start=1641
  _GETCLUSTERCONFIGREQ._serialized_end=1684
  _GETCLUSTERCONFIGRESP._serialized_start=1686
  _GETCLUSTERCONFIGRESP._serialized_end=1761
  _DETECTCLUSTERCONFIGREQ._serialized_start=1763
  _DETECTCLUSTERCONFIGREQ._serialized_end=1809
  _DETECTCLUSTERCONFIGRESP._serialized_start=1811
  _DETECTCLUSTERCONFIGRESP._serialized_end=1889
  _GETCLUSTERSTATUSREQ._serialized_start=1891
  _GETCLUSTERSTATUSREQ._serialized_end=1932
  _GETCLUSTERSTATUSRESP._serialized_start=1934
  _GETCLUSTERSTATUSRESP._serialized_end=2018
  _ENVIRONMENTMANAGER._serialized_start=2021
  _ENVIRONMENTMANAGER._serialized_end=3331
# @@protoc_insertion_point(module_scope)
